/* Sql to create database */
CREATE DATABASE IF NOT EXISTS sql_constraints_tutorial;

/* Use the newly created database */
USE sql_constraints_tutorial;

/* Query #1 :: Adding NOT NULL constraint on the table */
CREATE TABLE IF NOT EXISTS table1 (
    id INT(6) NOT NULL,
    fullname VARCHAR(10) NOT NULL,
    address VARCHAR(20)
);

/* Describes the table columns and their attributes. */
DESC table1;

/* Query #2 :: Adding UNIQUE constraint on the table */
CREATE TABLE IF NOT EXISTS table2 (
    id INT(6) NOT NULL UNIQUE,
    fullname VARCHAR(10),
    address VARCHAR(20)
);

/* Describes the table columns and their attributes. */
DESC table2;

/* Query #3 :: Adding PPRIMARY KEY constraint on the table */
CREATE TABLE IF NOT EXISTS table3 (
    id INT(6) NOT NULL,
    fullname VARCHAR(10),
    address VARCHAR(20),
    PRIMARY KEY (id)
);

/* Describes the table columns and their attributes. */
DESC table3;

/* Query #4 :: Adding FOREIGN KEY constraint on the table */
CREATE TABLE IF NOT EXISTS table4 (
    refid INT(10) NOT NULL,
    id INT(10),
    PRIMARY KEY (refid),
    FOREIGN KEY (id)
        REFERENCES table3 (id)
);

/* Describes the table columns and their attributes. */
DESC table4;

/* Query #5 :: Adding CHECK constraint on the table */
CREATE TABLE IF NOT EXISTS table5 (
    id INT(6) NOT NULL,
    fullname VARCHAR(10),
    address VARCHAR(20),
    age INT(5),
    CHECK (age >= 21)
);

/* Describes the table columns and their attributes. */
DESC table5;

/* Query #6 :: Adding DEFAULT constraint on the table */
CREATE TABLE IF NOT EXISTS table6 (
    id INT(6) NOT NULL,
    product_name VARCHAR(50) NOT NULL,
    product_manufacture_city VARCHAR(30) DEFAULT 'India'
);

/* Describes the table columns and their attributes. */
DESC table6;

/* ALTER query for adding a constraint to an existing table */
ALTER TABLE 'table_name' ADD CONSTRAINT 'constraint_name' 'constraint_type'

/* ALTER query for dropping a constraint from an existing table */
ALTER TABLE 'table_name' DROP CONSTRAINT 'constraint_name'